summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMatthias Clasen <mclasen@redhat.com>2006-06-16 17:22:30 +0000
committerMatthias Clasen <matthiasc@src.gnome.org>2006-06-16 17:22:30 +0000
commit60b0d8d6b0a14d6c5abb1248c25a89cff28b9958 (patch)
tree861f9175426964b2b6b473f9c39f7ba868d4de12
parent92bbb2fe7d76587e2e7445c38175186a7f25dae5 (diff)
downloadgtk+-60b0d8d6b0a14d6c5abb1248c25a89cff28b9958.tar.gz
Ignore unmapped widgets when ignore_hidden is TRUE. (#344707, Christian
2006-06-16 Matthias Clasen <mclasen@redhat.com> * gtk/gtksizegroup.c (compute_dimension): Ignore unmapped widgets when ignore_hidden is TRUE. (#344707, Christian Persch)
-rw-r--r--ChangeLog3
-rw-r--r--ChangeLog.pre-2-103
-rw-r--r--gtk/gtksizegroup.c10
3 files changed, 11 insertions, 5 deletions
diff --git a/ChangeLog b/ChangeLog
index f7bf490517..c4dc0df78b 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,5 +1,8 @@
2006-06-16 Matthias Clasen <mclasen@redhat.com>
+ * gtk/gtksizegroup.c (compute_dimension): Ignore unmapped widgets
+ when ignore_hidden is TRUE. (#344707, Christian Persch)
+
* configure.in: Require cvs glib.
* gtk/gtkprintoperation-unix.c:
diff --git a/ChangeLog.pre-2-10 b/ChangeLog.pre-2-10
index f7bf490517..c4dc0df78b 100644
--- a/ChangeLog.pre-2-10
+++ b/ChangeLog.pre-2-10
@@ -1,5 +1,8 @@
2006-06-16 Matthias Clasen <mclasen@redhat.com>
+ * gtk/gtksizegroup.c (compute_dimension): Ignore unmapped widgets
+ when ignore_hidden is TRUE. (#344707, Christian Persch)
+
* configure.in: Require cvs glib.
* gtk/gtkprintoperation-unix.c:
diff --git a/gtk/gtksizegroup.c b/gtk/gtksizegroup.c
index c1e4f68313..ecd42c0fd7 100644
--- a/gtk/gtksizegroup.c
+++ b/gtk/gtksizegroup.c
@@ -273,7 +273,7 @@ gtk_size_group_class_init (GtkSizeGroupClass *klass)
/**
* GtkSizeGroup:ignore-hidden:
*
* If %TRUE, hidden widgets are ignored when determining
* the size of the group.
*
* Since: 2.8
@@ -282,7 +282,7 @@ gtk_size_group_class_init (GtkSizeGroupClass *klass)
PROP_IGNORE_HIDDEN,
g_param_spec_boolean ("ignore-hidden",
P_("Ignore hidden"),
- P_("If TRUE, hidden widgets are ignored "
+ P_("If TRUE, unmapped widgets are ignored "
"when determining the size of the group"),
FALSE,
GTK_PARAM_READWRITE));
@@ -414,10 +414,10 @@ gtk_size_group_get_mode (GtkSizeGroup *size_group)
/**
* gtk_size_group_set_ignore_hidden:
* @size_group: a #GtkSizeGroup
* @ignore_hidden: whether hidden widgets should be ignored
* when calculating the size
*
* Sets whether invisible widgets should be ignored when
* calculating the size.
*
* Since: 2.8
@@ -632,7 +632,7 @@ compute_dimension (GtkWidget *widget,
gint dimension = compute_base_dimension (tmp_widget, mode);
- if (GTK_WIDGET_VISIBLE (tmp_widget) || !group->ignore_hidden)
+ if (GTK_WIDGET_MAPPED (tmp_widget) || !group->ignore_hidden)
{
if (dimension > result)
result = dimension;
@@ -273,7 +273,7 @@ gtk_size_group_class_init (GtkSizeGroupClass *klass)
* GtkSizeGroup:ignore-hidden:
*
- * If %TRUE, hidden widgets are ignored when determining
+ * If %TRUE, unmapped widgets are ignored when determining
* the size of the group.
*
@@ -414,10 +414,10 @@ gtk_size_group_get_mode (GtkSizeGroup *size_group)
* gtk_size_group_set_ignore_hidden:
* @size_group: a #GtkSizeGroup
- * @ignore_hidden: whether hidden widgets should be ignored
+ * @ignore_hidden: whether unmapped widgets should be ignored
* when calculating the size
*
@@ -414,10 +414,10 @@ gtk_size_group_get_mode (GtkSizeGroup *size_group)
* when calculating the size
*
- * Sets whether invisible widgets should be ignored when
+ * Sets whether unmapped widgets should be ignored when
* calculating the size.
*